bayespy.inference.vmp.transformations.RotateMultiple.bound
==========================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateMultiple.bound